
package ch.ethz.ssh2;

/**
 * A callback interface used to implement a client specific method of checking
 * server host keys.
 * 
 * @author Christian Plattner, plattner@inf.ethz.ch
 * @version $Id: ServerHostKeyVerifier.java,v 1.1 2005/05/23 09:03:29
 *          cplattne Exp $
 */

public interface ServerHostKeyVerifier
{

	/**
	 * The actual callback procedure, it will be called by the key exchange code
	 * on EVERY key exchange - this can happen several times during the lifetime
	 * of a connection.<br>
	 * Note: SSH2 servers are allowed to change their hostkey at ANY time.
	 * 
	 * @param hostname
	 * @param port
	 * @param serverHostKeyAlgorithm
	 * @param serverHostKey
	 * @return if the client wants to accept the server's host key - if not, the
	 *         connection will be closed.
	 */
	public boolean verifyServerHostKey(String hostname, int port, String serverHostKeyAlgorithm, byte[] serverHostKey);
}
